@@ -120,10 +120,13 @@ end;
 # Don't do complete until <prog> is hit
 function %(complete_func)s_condition;
     set -l COMP_WORDS (commandline -op)
-    set -l comp_script $COMP_WORDS[1] -m pyparam
+    set -l comp_script %(complete_script)s
     set -l len_words (count $COMP_WORDS)
     set -l len_script (count $comp_script)
     set -l incomplete (commandline -t)
+    if [ $len_script -eq 1 ];
+        return 0;
+    end
     # we haven't hit the script or module
     # go ahead do the complete only when
     # len_words > len_script
@@ -294,21 +297,6 @@ class Completer:
             else:
                 yield '\t'.join((comp[0] or ' ', comp[1]))
 
-    def _all_params(self) -> List[Type['Param']]:
-        """All parameters under this command
-
-        self.params don't have all of them, since namespaced ones are under
-        namespace paramters
-        """
-        ret: List[Type['Param']] = []
-        ret_append: Callable = ret.append
-        for param in self.params.values():
-            if param not in ret:
-                ret_append(param)
-            if param.type == 'ns':
-                ret.extend(param.decendents)
-        return ret
-
     def shellcode(self,
                   shell: str,
                   python: Optional[str] = None,
@@ -398,7 +386,7 @@ class Completer:
 
     def _get_param_by_prefixed(self, prefixed: str) -> Optional[Type['Param']]:
         """Get the parameter by the given prefixed name"""
-        for param in self._all_params():
+        for param in self._all_params(True):
             if any(param._prefix_name(name) == prefixed
                    for name in param.names):
                 return param
@@ -426,7 +414,7 @@ class Completer:
         unmatched_required: bool = False
         matched: List[Type['Param']] = []
         matched_append: Callable = matched.append
-        for param in self._all_params():
+        for param in self._all_params(True):
             if any(param._prefix_name(name) in self.comp_words
                    for name in param.names):
                 matched_append(param)
@@ -496,7 +484,7 @@ class Completer:
                 return # StopIteration, dont go further
 
         # no param or completions == ''
-        for param in self._all_params():
+        for param in self._all_params(True):
             if param.type == 'ns':
                 continue
             if param in completed and not param.complete_relapse:
