@@ -3,11 +3,11 @@
 class PyParamException(Exception):
     """Base exception for pyparam"""
 
-class PyParamTypeError(PyParamException, TypeError):
+class PyParamTypeError(PyParamException):
     """When parameter type is not supported"""
 
-class PyParamValueError(PyParamException, ValueError):
+class PyParamValueError(PyParamException):
     """When parameter value is improper"""
 
-class PyParamNameError(PyParamException, NameError):
+class PyParamNameError(PyParamException):
     """Any errors related to parameter names"""
